@@ -15,7 +15,8 @@ from tornado import escape
 from tornado.wsgi import WSGIContainer
 from tornado.ioloop import IOLoop
 from tornado.web import Application, FallbackHandler
-from .handlers import LiveReloadHandler, LiveReloadJSHandler, StaticHandler
+from .handlers import LiveReloadHandler, LiveReloadJSHandler
+from .handlers import ForceReloadHandler, StaticHandler
 from .watcher import Watcher
 from ._compat import text_types
 from tornado.log import enable_pretty_logging
@@ -90,8 +91,8 @@ class WSGIWrapper(WSGIContainer):
         header_set = set(k.lower() for (k, v) in headers)
         body = escape.utf8(body)
         body = body.replace(
-            '</head>',
-            '<script src="/livereload.js"></script></head>'
+            b'</head>',
+            b'<script src="/livereload.js"></script></head>'
         )
 
         if status_code != 304:
@@ -159,10 +160,11 @@ class Server(object):
 
         self.watcher.watch(filepath, func)
 
-    def application(self):
+    def application(self, debug=True):
         LiveReloadHandler.watcher = self.watcher
         handlers = [
             (r'/livereload', LiveReloadHandler),
+            (r'/forcereload', ForceReloadHandler),
             (r'/livereload.js', LiveReloadJSHandler, dict(port=self.port)),
         ]
 
@@ -175,21 +177,23 @@ class Server(object):
             handlers.append(
                 (r'(.*)', StaticHandler, dict(root=self.root or '.')),
             )
-        return Application(handlers=handlers, debug=True)
+        return Application(handlers=handlers, debug=debug)
 
-    def serve(self, port=None, root=None):
+    def serve(self, port=None, host=None, root=None, debug=True):
         """Start serve the server with the given port.
 
         :param port: serve on this port, default is 5500
+        :param host: serve on this hostname, default is 0.0.0.0
         :param root: serve static on this root directory
         """
         if root:
             self.root = root
-
         if port:
             self.port = port
+        if host is None:
+            host = ''
 
-        self.application().listen(self.port)
+        self.application(debug=debug).listen(self.port, address=host)
         logging.getLogger().setLevel(logging.INFO)
         print('Serving on 127.0.0.1:%s' % self.port)
         try:
